from Globals import DTMLFile, MessageDialog, Persistent
import OFS
import Acquisition
import AccessControl.Role
from Products import ZCatalog
import Base
import Issue
import time

manage_addIssueManagerForm = DTMLFile('issueManagerAdd', globals()) 

css = """
body {
	background-color: #fff;
	color: #000000;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 12px;
}

a {
	text-decoration: none;
	color: #436976;
	background-color: transparent;
}

a:hover {
	color: #769ca9;
	background-color: transparent;
}

table {
	border: 0px;
}

#main {
	width: 65%;
	border: none 1px #ccc;
	padding: 3px;
}

#breadcrumbs {
        padding: 5px;
        width: 65%;
}

input {
	border: 1px dotted #999;
	background-color: #fff;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 10px;
	font-weight: bolder;
	cursor : pointer;
}

textarea {
	border: 1px dotted #999;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 10px;
	font-weight: bolder;
}

th {
	text-align: left;
       	vertical-align: top;
}

td {
	text-align: left;
       	vertical-align: top;
}

#copyright {
	position: absolute;
	right: 10px;
	bottom: 10px;
}

h1, h2, h3, h4, h5, h6 {
	font-weight: bolder;
}

h1 {
    font-size: 150%;
}

h2 {
    font-size: 140%;
}

h3 {
    font-size: 130%;
}

h4 {
    font-size: 110%;
}

h5 {
    font-size: 80%;
}

h6 {
    font-size: 60%;
}
"""

def manage_addIssueManager(self, id, title='', REQUEST=None):
    """Add an IssueManager."""
    self._setObject(id, IssueManager(id, title))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

class IssueManager(
    OFS.Folder.Folder,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager,
    Base.Base,
    ): 
    """IssueManager object. 

    An IssueManager contains Issues.
    """

    meta_type = 'Issue Manager'

    manage_options = (OFS.Folder.Folder.manage_options[0],) + \
        (
            {'label': 'Edit',       'action': 'manage_edit_properties'},
            {'label': 'View',       'action': ''},
            {'label': 'Security',   'action': 'manage_access'},
        ) 

    __ac_permissions__=(
	('View management screens', ('manage_tabs','manage_main',
                                     'manage_workspace')),
	('Change permissions', ('manage_access',)),
	('Edit IssueManager', ('manage_edit',)),
	('View IssueManager', ('',)),
        ('Add Issue', ('manage_addIssue',)),
    )

    index_html = DTMLFile('productIndex', globals())
    issue_listing = DTMLFile('issueListing', globals())
    manage_addIssue = Issue.manage_addIssue
    css = css

    def get_issues(self):
        """Returns a list of the Issues contained."""
        return self.objectValues('Issue')

    def get_unique_id(self):
        """Returns a unique identifier."""
        # This is good enough for now
        integer, float = str(time.time()).split('.')
        return integer + 'X' + float

    def __init__(self, id, title=''):
        self.id = id
        self.title = title
        ZCatalog.ZCatalog.manage_addZCatalog(self, 'Catalog', 'Issue catalog')
        self.Catalog.manage_addIndex('contents', 'TextIndex')
        self.Catalog.manage_addIndex('get_all_text', 'TextIndex')
        self.Catalog.manage_addColumn('contents')
        self.Catalog.manage_addColumn('absolute_url')
