from Globals import DTMLFile, MessageDialog, Persistent
import OFS
import Acquisition
import AccessControl.Role
from Products import ZCatalog
import base
from StructuredText.StructuredText import HTML

def manage_add_issue(self, id=None, title='', contents='', format='',
                     state='', referrer='', REQUEST=None):
    """Add an Issue."""
    if id is None:
        id = self.get_unique_id()
    issue_ = issue(id, title, contents, format, state)
    self._setObject(id, issue_)
    if referrer and REQUEST is not None:
        REQUEST.RESPONSE.redirect(referrer)
    else:
        if REQUEST is not None:
            return self.manage_main(self, REQUEST)
        else:
            return issue_

def manage_add_issue_edit(self, id=None, title='', contents='', referrer='',
                          state='', REQUEST=None):
    """Adds an issue and redirects to the edit page."""
    issue_ = manage_add_issue(self, id=id, title=title, contents=contents, referrer=referrer, state=state)
    REQUEST.RESPONSE.redirect(self.absolute_url() + '/' + issue_.id + '/issue_edit')

class issue(
    ZCatalog.CatalogAwareness.CatalogAware,
    OFS.Folder.Folder,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager,
    base.base
    ): 
    """Issue class.

    An issue contains information relating to a task, an
    idea, or whatever.
    """

    meta_type = 'Issue'
    state = 'open'

    all_meta_types = [
        {'visibility': 'Global',
         'interfaces': [],
         'action': 'manage_add_issue',
         'permission': 'Add Issues',
         'name': 'Issue',
         'product': 'Issue Manager',
         'instance': ''}
    ]

    manage_options = (OFS.Folder.Folder.manage_options[0],) + \
        (
            {'label': 'View',       'action': ''},
            {'label': 'Security',   'action': 'manage_access'},
        ) 

    __ac_permissions__=(
	('View management screens', ('manage_tabs','manage_main',
                                     'manage_workspace')),
	('Cut and paste issues', ('manage_cut', 'manage_paste')),
	('Delete issues', ('manage_delete',)),
	('Change permissions', ('manage_access',)),
	('Edit issues', ('issue_edit',)),
	('View issues', ('',)),
    )

    def __init__(self, id, title='', contents='', format='', state=''): 
        """initialise a new instance of Issue"""
        self.id = id
        self.title = title
        self.contents = contents
        self.format = format or 'text'
        self.state = state or 'open'

    def render_stx_as_html(self):
        """Renders the contents as STX."""
        return HTML(self.contents, level=3, header=0)

    def manage_edit(self, title, contents, format, state, REQUEST=None):
        """Edits the object."""
        self.title = title
        self.contents = contents
        self.format = format
        self.state = state
        self.index_object()
        if REQUEST is not None:
            REQUEST.RESPONSE.redirect(self.absolute_url())

    index_html = DTMLFile('index', globals())
    manage_add_issue = manage_add_issue
    manage_add_issue_edit = manage_add_issue_edit
    issue_edit = DTMLFile('issue_edit', globals())
    render_contents = DTMLFile('issue_render_contents', globals())
