from Globals import DTMLFile, MessageDialog, Persistent
import OFS
import Acquisition
import AccessControl.Role
from Products import ZCatalog
import base
import issue
import time

manage_add_issue_manager_form = DTMLFile('issue_manager_add', globals()) 

css = """
body {
	background-color: #fff;
	color: #000000;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 12px;
}

a {
	text-decoration: none;
	color: #436976;
	background-color: transparent;
}

a:hover {
	color: #769ca9;
	background-color: transparent;
}

table {
	border: 0px;
}

#main {
	width: 65%;
	border: none 1px #ccc;
	padding: 3px;
}

#breadcrumbs {
        padding: 5px;
        width: 65%;
}

input {
	border: 1px dotted #999;
	background-color: #fff;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 10px;
	font-weight: bolder;
	cursor : pointer;
}

pre {
	font-family: verdana, helvetica, arial, sans-serif;
}

textarea {
	border: 1px dotted #999;
	font-family: verdana, helvetica, arial, sans-serif;
	font-size: 10px;
	font-weight: bolder;
}

th {
	text-align: left;
       	vertical-align: top;
}

td {
	text-align: left;
       	vertical-align: top;
}

#copyright {}

h1, h2, h3, h4, h5, h6 {
	font-weight: bolder;
}

h1 {
    font-size: 150%;
}

h2 {
    font-size: 140%;
}

h3 {
    font-size: 130%;
}

h4 {
    font-size: 110%;
}

h5 {
    font-size: 80%;
}

h6 {
    font-size: 60%;
}
"""

def manage_add_issue_manager(self, id, title='', REQUEST=None):
    """Add an Issue Manager."""
    self._setObject(id, issue_manager(id, title))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

class issue_manager(
    OFS.Folder.Folder,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager,
    base.base,
    ): 
    """Issue Manager class. 

    An issueManager contains Issues.
    """

    meta_type = 'Issue Manager'

    manage_options = (OFS.Folder.Folder.manage_options[0],) + \
        (
            {'label': 'View',       'action': ''},
            {'label': 'Security',   'action': 'manage_access'},
        ) 

    __ac_permissions__=(
	('View management screens', ('manage_tabs','manage_main',
                                     'manage_workspace')),
	('Change permissions', ('manage_access',)),
	('View Issue Managers', ('',)),
        ('Add Issue', ('manage_add_issue',)),
    )

    all_meta_types = [
        {'visibility': 'Global',
         'interfaces': [],
         'action': 'manage_add_issue',
         'permission': 'Add Issues',
         'name': 'Issue',
         'product': 'Issue Manager',
         'instance': ''}
    ]

    index_html = DTMLFile('product_index', globals())
    manage_add_issue = issue.manage_add_issue
    manage_add_issue_edit = issue.manage_add_issue_edit
    css = css

    def get_unique_id(self):
        """Returns a unique identifier."""
        # This is good enough for now
        integer, float = str(time.time()).split('.')
        return integer + 'X' + float

    def __init__(self, id, title=''):
        self.id = id
        self.title = title
        ZCatalog.ZCatalog.manage_addZCatalog(self, 'Catalog', 'Issue catalog')
        # Indexes
        self.Catalog.manage_addIndex('type', 'FieldIndex')
        self.Catalog.manage_addIndex('state', 'FieldIndex')
        self.Catalog.manage_addIndex('get_parent_url', 'FieldIndex')
        self.Catalog.manage_addIndex('contents', 'TextIndex')
        self.Catalog.manage_addIndex('get_all_text', 'TextIndex')
        # Columns
        self.Catalog.manage_addColumn('contents')
        self.Catalog.manage_addColumn('absolute_url')
        self.Catalog.manage_addColumn('state')
        self.Catalog.manage_addColumn('type')
        self.Catalog.manage_addColumn('get_title')
        self.Catalog.manage_addColumn('get_number_of_issues')
